# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qm/pb/job_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from qm.pb import errors_pb2 as qm_dot_pb_dot_errors__pb2
from qm.pb import general_messages_pb2 as qm_dot_pb_dot_general__messages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='qm/pb/job_manager.proto',
  package='qm.grpc.jobManager',
  syntax='proto3',
  serialized_options=b'\n\022qm.grpc.jobManagerB\026JobManagerServiceProtoP\001\242\002\003HLW',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17qm/pb/job_manager.proto\x12\x12qm.grpc.jobManager\x1a\x12qm/pb/errors.proto\x1a\x1cqm/pb/general_messages.proto\"r\n\x1bGetElementCorrectionRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x0e\n\x06qeName\x18\x02 \x01(\t\x12\x34\n\ncorrection\x18\x03 \x01(\x0b\x32 .qm.grpc.general_messages.Matrix\"\xa4\x01\n\x1cGetElementCorrectionResponse\x12N\n\x18jobManagerResponseHeader\x18\x01 \x01(\x0b\x32,.qm.grpc.jobManager.JobManagerResponseHeader\x12\x34\n\ncorrection\x18\x03 \x01(\x0b\x32 .qm.grpc.general_messages.Matrix\"r\n\x1bSetElementCorrectionRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x0e\n\x06qeName\x18\x02 \x01(\t\x12\x34\n\ncorrection\x18\x03 \x01(\x0b\x32 .qm.grpc.general_messages.Matrix\"\xa4\x01\n\x1cSetElementCorrectionResponse\x12N\n\x18jobManagerResponseHeader\x18\x01 \x01(\x0b\x32,.qm.grpc.jobManager.JobManagerResponseHeader\x12\x34\n\ncorrection\x18\x02 \x01(\x0b\x32 .qm.grpc.general_messages.Matrix\"\xac\x01\n\x18JobManagerResponseHeader\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05jobId\x18\x02 \x01(\t\x12\x32\n\x13jobManagerErrorType\x18\n \x01(\x0e\x32\x15.JobManagerErrorTypes\x12<\n\x0fjobErrorDetails\x18\x0b \x01(\x0b\x32#.qm.grpc.jobManager.JobErrorDetails\"\xb1\x01\n\x0fJobErrorDetails\x12H\n\x1djobOperationSpecificErrorType\x18\x01 \x01(\x0e\x32\x1f.JobOperationSpecificErrorTypesH\x00\x12\x36\n\x14\x63onfigQueryErrorType\x18\x02 \x01(\x0e\x32\x16.ConfigQueryErrorTypesH\x00\x12\x0f\n\x07message\x18\n \x01(\tB\x0b\n\terrorType\"[\n\x19JobOperationSpecificError\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.JobOperationSpecificErrorTypes\x12\x0f\n\x07message\x18\x02 \x01(\t2\x8d\x02\n\x11JobManagerService\x12{\n\x14GetElementCorrection\x12/.qm.grpc.jobManager.GetElementCorrectionRequest\x1a\x30.qm.grpc.jobManager.GetElementCorrectionResponse\"\x00\x12{\n\x14SetElementCorrection\x12/.qm.grpc.jobManager.SetElementCorrectionRequest\x1a\x30.qm.grpc.jobManager.SetElementCorrectionResponse\"\x00\x42\x34\n\x12qm.grpc.jobManagerB\x16JobManagerServiceProtoP\x01\xa2\x02\x03HLWb\x06proto3'
  ,
  dependencies=[qm_dot_pb_dot_errors__pb2.DESCRIPTOR,qm_dot_pb_dot_general__messages__pb2.DESCRIPTOR,])




_GETELEMENTCORRECTIONREQUEST = _descriptor.Descriptor(
  name='GetElementCorrectionRequest',
  full_name='qm.grpc.jobManager.GetElementCorrectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.jobManager.GetElementCorrectionRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qeName', full_name='qm.grpc.jobManager.GetElementCorrectionRequest.qeName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='correction', full_name='qm.grpc.jobManager.GetElementCorrectionRequest.correction', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=211,
)


_GETELEMENTCORRECTIONRESPONSE = _descriptor.Descriptor(
  name='GetElementCorrectionResponse',
  full_name='qm.grpc.jobManager.GetElementCorrectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobManagerResponseHeader', full_name='qm.grpc.jobManager.GetElementCorrectionResponse.jobManagerResponseHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='correction', full_name='qm.grpc.jobManager.GetElementCorrectionResponse.correction', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=378,
)


_SETELEMENTCORRECTIONREQUEST = _descriptor.Descriptor(
  name='SetElementCorrectionRequest',
  full_name='qm.grpc.jobManager.SetElementCorrectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.jobManager.SetElementCorrectionRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qeName', full_name='qm.grpc.jobManager.SetElementCorrectionRequest.qeName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='correction', full_name='qm.grpc.jobManager.SetElementCorrectionRequest.correction', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=380,
  serialized_end=494,
)


_SETELEMENTCORRECTIONRESPONSE = _descriptor.Descriptor(
  name='SetElementCorrectionResponse',
  full_name='qm.grpc.jobManager.SetElementCorrectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobManagerResponseHeader', full_name='qm.grpc.jobManager.SetElementCorrectionResponse.jobManagerResponseHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='correction', full_name='qm.grpc.jobManager.SetElementCorrectionResponse.correction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=661,
)


_JOBMANAGERRESPONSEHEADER = _descriptor.Descriptor(
  name='JobManagerResponseHeader',
  full_name='qm.grpc.jobManager.JobManagerResponseHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='qm.grpc.jobManager.JobManagerResponseHeader.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.jobManager.JobManagerResponseHeader.jobId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobManagerErrorType', full_name='qm.grpc.jobManager.JobManagerResponseHeader.jobManagerErrorType', index=2,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobErrorDetails', full_name='qm.grpc.jobManager.JobManagerResponseHeader.jobErrorDetails', index=3,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=664,
  serialized_end=836,
)


_JOBERRORDETAILS = _descriptor.Descriptor(
  name='JobErrorDetails',
  full_name='qm.grpc.jobManager.JobErrorDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobOperationSpecificErrorType', full_name='qm.grpc.jobManager.JobErrorDetails.jobOperationSpecificErrorType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configQueryErrorType', full_name='qm.grpc.jobManager.JobErrorDetails.configQueryErrorType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='qm.grpc.jobManager.JobErrorDetails.message', index=2,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='errorType', full_name='qm.grpc.jobManager.JobErrorDetails.errorType',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=839,
  serialized_end=1016,
)


_JOBOPERATIONSPECIFICERROR = _descriptor.Descriptor(
  name='JobOperationSpecificError',
  full_name='qm.grpc.jobManager.JobOperationSpecificError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='qm.grpc.jobManager.JobOperationSpecificError.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='qm.grpc.jobManager.JobOperationSpecificError.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1018,
  serialized_end=1109,
)

_GETELEMENTCORRECTIONREQUEST.fields_by_name['correction'].message_type = qm_dot_pb_dot_general__messages__pb2._MATRIX
_GETELEMENTCORRECTIONRESPONSE.fields_by_name['jobManagerResponseHeader'].message_type = _JOBMANAGERRESPONSEHEADER
_GETELEMENTCORRECTIONRESPONSE.fields_by_name['correction'].message_type = qm_dot_pb_dot_general__messages__pb2._MATRIX
_SETELEMENTCORRECTIONREQUEST.fields_by_name['correction'].message_type = qm_dot_pb_dot_general__messages__pb2._MATRIX
_SETELEMENTCORRECTIONRESPONSE.fields_by_name['jobManagerResponseHeader'].message_type = _JOBMANAGERRESPONSEHEADER
_SETELEMENTCORRECTIONRESPONSE.fields_by_name['correction'].message_type = qm_dot_pb_dot_general__messages__pb2._MATRIX
_JOBMANAGERRESPONSEHEADER.fields_by_name['jobManagerErrorType'].enum_type = qm_dot_pb_dot_errors__pb2._JOBMANAGERERRORTYPES
_JOBMANAGERRESPONSEHEADER.fields_by_name['jobErrorDetails'].message_type = _JOBERRORDETAILS
_JOBERRORDETAILS.fields_by_name['jobOperationSpecificErrorType'].enum_type = qm_dot_pb_dot_errors__pb2._JOBOPERATIONSPECIFICERRORTYPES
_JOBERRORDETAILS.fields_by_name['configQueryErrorType'].enum_type = qm_dot_pb_dot_errors__pb2._CONFIGQUERYERRORTYPES
_JOBERRORDETAILS.oneofs_by_name['errorType'].fields.append(
  _JOBERRORDETAILS.fields_by_name['jobOperationSpecificErrorType'])
_JOBERRORDETAILS.fields_by_name['jobOperationSpecificErrorType'].containing_oneof = _JOBERRORDETAILS.oneofs_by_name['errorType']
_JOBERRORDETAILS.oneofs_by_name['errorType'].fields.append(
  _JOBERRORDETAILS.fields_by_name['configQueryErrorType'])
_JOBERRORDETAILS.fields_by_name['configQueryErrorType'].containing_oneof = _JOBERRORDETAILS.oneofs_by_name['errorType']
_JOBOPERATIONSPECIFICERROR.fields_by_name['type'].enum_type = qm_dot_pb_dot_errors__pb2._JOBOPERATIONSPECIFICERRORTYPES
DESCRIPTOR.message_types_by_name['GetElementCorrectionRequest'] = _GETELEMENTCORRECTIONREQUEST
DESCRIPTOR.message_types_by_name['GetElementCorrectionResponse'] = _GETELEMENTCORRECTIONRESPONSE
DESCRIPTOR.message_types_by_name['SetElementCorrectionRequest'] = _SETELEMENTCORRECTIONREQUEST
DESCRIPTOR.message_types_by_name['SetElementCorrectionResponse'] = _SETELEMENTCORRECTIONRESPONSE
DESCRIPTOR.message_types_by_name['JobManagerResponseHeader'] = _JOBMANAGERRESPONSEHEADER
DESCRIPTOR.message_types_by_name['JobErrorDetails'] = _JOBERRORDETAILS
DESCRIPTOR.message_types_by_name['JobOperationSpecificError'] = _JOBOPERATIONSPECIFICERROR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetElementCorrectionRequest = _reflection.GeneratedProtocolMessageType('GetElementCorrectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETELEMENTCORRECTIONREQUEST,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.GetElementCorrectionRequest)
  })
_sym_db.RegisterMessage(GetElementCorrectionRequest)

GetElementCorrectionResponse = _reflection.GeneratedProtocolMessageType('GetElementCorrectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETELEMENTCORRECTIONRESPONSE,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.GetElementCorrectionResponse)
  })
_sym_db.RegisterMessage(GetElementCorrectionResponse)

SetElementCorrectionRequest = _reflection.GeneratedProtocolMessageType('SetElementCorrectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETELEMENTCORRECTIONREQUEST,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.SetElementCorrectionRequest)
  })
_sym_db.RegisterMessage(SetElementCorrectionRequest)

SetElementCorrectionResponse = _reflection.GeneratedProtocolMessageType('SetElementCorrectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETELEMENTCORRECTIONRESPONSE,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.SetElementCorrectionResponse)
  })
_sym_db.RegisterMessage(SetElementCorrectionResponse)

JobManagerResponseHeader = _reflection.GeneratedProtocolMessageType('JobManagerResponseHeader', (_message.Message,), {
  'DESCRIPTOR' : _JOBMANAGERRESPONSEHEADER,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.JobManagerResponseHeader)
  })
_sym_db.RegisterMessage(JobManagerResponseHeader)

JobErrorDetails = _reflection.GeneratedProtocolMessageType('JobErrorDetails', (_message.Message,), {
  'DESCRIPTOR' : _JOBERRORDETAILS,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.JobErrorDetails)
  })
_sym_db.RegisterMessage(JobErrorDetails)

JobOperationSpecificError = _reflection.GeneratedProtocolMessageType('JobOperationSpecificError', (_message.Message,), {
  'DESCRIPTOR' : _JOBOPERATIONSPECIFICERROR,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.JobOperationSpecificError)
  })
_sym_db.RegisterMessage(JobOperationSpecificError)


DESCRIPTOR._options = None

_JOBMANAGERSERVICE = _descriptor.ServiceDescriptor(
  name='JobManagerService',
  full_name='qm.grpc.jobManager.JobManagerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1112,
  serialized_end=1381,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetElementCorrection',
    full_name='qm.grpc.jobManager.JobManagerService.GetElementCorrection',
    index=0,
    containing_service=None,
    input_type=_GETELEMENTCORRECTIONREQUEST,
    output_type=_GETELEMENTCORRECTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetElementCorrection',
    full_name='qm.grpc.jobManager.JobManagerService.SetElementCorrection',
    index=1,
    containing_service=None,
    input_type=_SETELEMENTCORRECTIONREQUEST,
    output_type=_SETELEMENTCORRECTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_JOBMANAGERSERVICE)

DESCRIPTOR.services_by_name['JobManagerService'] = _JOBMANAGERSERVICE

# @@protoc_insertion_point(module_scope)
